==> eudcc-0.0.1.tar.gz: lib/certificates/certificate.dart <==
import 'package:eudcc/certificates/recovery.dart';
import 'package:eudcc/certificates/test.dart';
import 'package:json_annotation/json_annotation.dart';

import 'vaccine.dart';
import 'identity.dart';

part 'certificate.g.dart';

class BirthDate {
  final int? year;
  final int? month;
  final int? day;

  const BirthDate({this.year, this.month, this.day});

  static BirthDate fromJsonKey(String value) {
    var l = value.isNotEmpty ? value.split("-") : [];
    return BirthDate(
        year: l.isNotEmpty ? int.parse(l[0]) : null,
        month: l.length > 1 ? int.parse(l[1]) : null,
        day: l.length > 2 ? int.parse(l[2]) : null);
  }

  static String toJsonKey(BirthDate dob) {
    return dob.toString();
  }

  @override
  String toString() {
    String repr = "";
    repr += year?.toString().padLeft(4, '0') ?? "XXXX";
    repr += "-";
    repr += month?.toString().padLeft(2, '0') ?? "XX";
    repr += "-";
    repr += day?.toString().padLeft(2, '0') ?? "XX";
    return repr;
  }

  DateTime toDateTime() {
    return DateTime(year ?? 0, month ?? 0, day ?? 0);
  }
}

@JsonSerializable()
class Certificate {
  @JsonKey(name: "ver", required: true)
  final String version;

  @JsonKey(
      name: "dob",
      required: true,
      fromJson: BirthDate.fromJsonKey,
      toJson: BirthDate.toJsonKey)
  final BirthDate dateOfBirth;

  @JsonKey(name: "nam", required: true)
  final Identity holder;

  @JsonKey(name: "v", required: false)
  final List<Vaccine>? vaccines;

  @JsonKey(name: "t", required: false)
  final List<Test>? tests;

  @JsonKey(name: "r", required: false)
  final List<Recovery>? recoveries;

  Certificate(this.version, this.dateOfBirth, this.holder, this.vaccines,
      this.tests, this.recoveries);

  factory Certificate.fromJson(Map<String, dynamic> json) =>
      _$CertificateFromJson(json);

  Map<String, dynamic> toJson() => _$CertificateToJson(this);
}

==> eudcc-0.0.4.tar.gz: lib/certificates/certificate.dart <==
import 'package:eudcc/certificates/recovery.dart';
import 'package:eudcc/certificates/test.dart';
import 'package:json_annotation/json_annotation.dart';

import 'vaccine.dart';
import 'identity.dart';

part 'certificate.g.dart';

class BirthDate {
  final int? year;
  final int? month;
  final int? day;

  const BirthDate({this.year, this.month, this.day});

  static BirthDate fromJsonKey(String value) {
    var l = value.isNotEmpty ? value.split("-") : [];
    return BirthDate(
        year: l.isNotEmpty ? int.parse(l[0]) : null,
        month: l.length > 1 ? int.parse(l[1]) : null,
        day: l.length > 2 ? int.parse(l[2]) : null);
  }

  static String toJsonKey(BirthDate dob) {
    return dob.toString();
  }

  @override
  String toString() {
    String repr = "";
    repr += year?.toString().padLeft(4, '0') ?? "XXXX";
    repr += "-";
    repr += month?.toString().padLeft(2, '0') ?? "XX";
    repr += "-";
    repr += day?.toString().padLeft(2, '0') ?? "XX";
    return repr;
  }

  DateTime toDateTime() {
    return DateTime.utc(year ?? 0, month ?? 0, day ?? 0);
  }
}

@JsonSerializable()
class Certificate {
  @JsonKey(name: "ver", required: true)
  final String version;

  @JsonKey(
      name: "dob",
      required: true,
      fromJson: BirthDate.fromJsonKey,
      toJson: BirthDate.toJsonKey)
  final BirthDate dateOfBirth;

  @JsonKey(name: "nam", required: true)
  final Identity holder;

  @JsonKey(name: "v", required: false)
  final List<Vaccine>? vaccines;

  @JsonKey(name: "t", required: false)
  final List<Test>? tests;

  @JsonKey(name: "r", required: false)
  final List<Recovery>? recoveries;

  Certificate(this.version, this.dateOfBirth, this.holder, this.vaccines,
      this.tests, this.recoveries);

  factory Certificate.fromJson(Map<String, dynamic> json) =>
      _$CertificateFromJson(json);

  Map<String, dynamic> toJson() => _$CertificateToJson(this);
}
